﻿/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2010 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Estonian language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Voldi tööriistariba",
ToolbarExpand		: "Laienda tööriistariba",

// Toolbar Items and Context Menu
Save				: "Salvesta",
NewPage				: "Uus leht",
Preview				: "Eelvaade",
Cut					: "Lõika",
Copy				: "Kopeeri",
Paste				: "Kleebi",
PasteText			: "Kleebi tavalise tekstina",
PasteWord			: "Kleebi Wordist",
Print				: "Prindi",
SelectAll			: "Vali kõik",
RemoveFormat		: "Eemalda vorming",
InsertLinkLbl		: "Link",
InsertLink			: "Sisesta link / Muuda linki",
RemoveLink			: "Eemalda link",
VisitLink			: "Open Link",	//MISSING
Anchor				: "Sisesta ankur / Muuda ankrut",
AnchorDelete		: "Eemalda ankur",
InsertImageLbl		: "Pilt",
InsertImage			: "Sisesta pilt / Muuda pilti",
InsertFlashLbl		: "Flash",
InsertFlash			: "Sisesta flash / Muuda flashi",
InsertTableLbl		: "Tabel",
InsertTable			: "Sisesta tabel / Muuda tabelit",
InsertLineLbl		: "Joon",
InsertLine			: "Sisesta horisontaaljoon",
InsertSpecialCharLbl: "Erimärgid",
InsertSpecialChar	: "Sisesta erimärk",
InsertSmileyLbl		: "Emotikon",
InsertSmiley		: "Sisesta emotikon",
About				: "FCKeditor teave",
Bold				: "Paks",
Italic				: "Kursiiv",
Underline			: "Allajoonitud",
StrikeThrough		: "Läbijoonitud",
Subscript			: "Allindeks",
Superscript			: "Ülaindeks",
LeftJustify			: "Vasakjoondus",
CenterJustify		: "Keskjoondus",
RightJustify		: "Paremjoondus",
BlockJustify		: "Rööpjoondus",
DecreaseIndent		: "Vähenda taanet",
IncreaseIndent		: "Suurenda taanet",
Blockquote			: "Blokktsitaat",
CreateDiv			: "Create Div Container",	//MISSING
EditDiv				: "Edit Div Container",	//MISSING
DeleteDiv			: "Remove Div Container",	//MISSING
Undo				: "Võta tagasi",
Redo				: "Korda toimingut",
NumberedListLbl		: "Nummerdatud loetelu",
NumberedList		: "Sisesta/Eemalda nummerdatud loetelu",
BulletedListLbl		: "Punktiseeritud loetelu",
BulletedList		: "Sisesta/Eemalda punktiseeritud loetelu",
ShowTableBorders	: "Näita tabeli jooni",
ShowDetails			: "Näita üksikasju",
Style				: "Laad",
FontFormat			: "Vorming",
Font				: "Kiri",
FontSize			: "Suurus",
TextColor			: "Teksti värv",
BGColor				: "Tausta värv",
Source				: "Lähtekood",
Find				: "Otsi",
Replace				: "Asenda",
SpellCheck			: "Kontrolli õigekirja",
UniversalKeyboard	: "Universaalne klaviatuur",
PageBreakLbl		: "Lehepiir",
PageBreak			: "Sisesta lehevahetuskoht",

Form			: "Vorm",
Checkbox		: "Märkeruut",
RadioButton		: "Raadionupp",
TextField		: "Tekstilahter",
Textarea		: "Tekstiala",
HiddenField		: "Varjatud lahter",
Button			: "Nupp",
SelectionField	: "Valiklahter",
ImageButton		: "Piltnupp",

FitWindow		: "Maksimeeri redaktori mõõtmed",
ShowBlocks		: "Näita blokke",

// Context Menu
EditLink			: "Muuda linki",
CellCM				: "Lahter",
RowCM				: "Rida",
ColumnCM			: "Veerg",
InsertRowAfter		: "Sisesta rida peale",
InsertRowBefore		: "Sisesta rida enne",
DeleteRows			: "Eemalda read",
InsertColumnAfter	: "Sisesta veerg peale",
InsertColumnBefore	: "Sisesta veerg enne",
DeleteColumns		: "Eemalda veerud",
InsertCellAfter		: "Sisesta lahter peale",
InsertCellBefore	: "Sisesta lahter enne",
DeleteCells			: "Eemalda lahtrid",
MergeCells			: "Ühenda lahtrid",
MergeRight			: "Ühenda paremale",
MergeDown			: "Ühenda alla",
HorizontalSplitCell	: "Poolita lahter horisontaalselt",
VerticalSplitCell	: "Poolita lahter vertikaalselt",
TableDelete			: "Kustuta tabel",
CellProperties		: "Lahtri atribuudid",
TableProperties		: "Tabeli atribuudid",
ImageProperties		: "Pildi atribuudid",
FlashProperties		: "Flash omadused",

AnchorProp			: "Ankru omadused",
ButtonProp			: "Nupu omadused",
CheckboxProp		: "Märkeruudu omadused",
HiddenFieldProp		: "Varjatud lahtri omadused",
RadioButtonProp		: "Raadionupu omadused",
ImageButtonProp		: "Piltnupu omadused",
TextFieldProp		: "Tekstilahtri omadused",
SelectionFieldProp	: "Valiklahtri omadused",
TextareaProp		: "Tekstiala omadused",
FormProp			: "Vormi omadused",

FontFormats			: "Tavaline;Vormindatud;Aadress;Pealkiri 1;Pealkiri 2;Pealkiri 3;Pealkiri 4;Pealkiri 5;Pealkiri 6;Tavaline (DIV)",

// Alerts and Messages
ProcessingXHTML		: "Töötlen XHTML'i. Palun oota...",
Done				: "Tehtud",
PasteWordConfirm	: "Tekst, mida soovid lisada paistab pärinevat Word'ist. Kas soovid seda enne kleepimist puhastada?",
NotCompatiblePaste	: "See käsk on saadaval ainult Internet Explorer versioon 5.5 või uuema puhul. Kas soovid kleepida ilma puhastamata?",
UnknownToolbarItem	: "Tundmatu tööriistarea üksus \"%1\"",
UnknownCommand		: "Tundmatu käsunimi \"%1\"",
NotImplemented		: "Käsku ei täidetud",
UnknownToolbarSet	: "Tööriistariba \"%1\" ei eksisteeri",
NoActiveX			: "Sinu veebisirvija turvalisuse seaded võivad limiteerida mõningaid tekstirdaktori kasutusvõimalusi. Sa peaksid võimaldama valiku \"Run ActiveX controls and plug-ins\" oma veebisirvija seadetes. Muidu võid sa täheldada vigu tekstiredaktori töös ja märgata puuduvaid funktsioone.",
BrowseServerBlocked : "Ressursside sirvija avamine ebaõnnestus. Võimalda pop-up akende avanemine.",
DialogBlocked		: "Ei olenud võimalik avada dialoogi akent. Võimalda pop-up akende avanemine.",
VisitLinkBlocked	: "It was not possible to open a new window. Make sure all popup blockers are disabled.",	//MISSING

// Dialogs
DlgBtnOK			: "OK",
DlgBtnCancel		: "Loobu",
DlgBtnClose			: "Sulge",
DlgBtnBrowseServer	: "Sirvi serverit",
DlgAdvancedTag		: "Täpsemalt",
DlgOpOther			: "<Teine>",
DlgInfoTab			: "Info",
DlgAlertUrl			: "Palun sisesta URL",

// General Dialogs Labels
DlgGenNotSet		: "<määramata>",
DlgGenId			: "Id",
DlgGenLangDir		: "Keele suund",
DlgGenLangDirLtr	: "Vasakult paremale (LTR)",
DlgGenLangDirRtl	: "Paremalt vasakule (RTL)",
DlgGenLangCode		: "Keele kood",
DlgGenAccessKey		: "Juurdepääsu võti",
DlgGenName			: "Nimi",
DlgGenTabIndex		: "Tab indeks",
DlgGenLongDescr		: "Pikk kirjeldus URL",
DlgGenClass			: "Stiilistiku klassid",
DlgGenTitle			: "Juhendav tiitel",
DlgGenContType		: "Juhendava sisu tüüp",
DlgGenLinkCharset	: "Lingitud ressurssi märgistik",
DlgGenStyle			: "Laad",

// Image Dialog
DlgImgTitle			: "Pildi atribuudid",
DlgImgInfoTab		: "Pildi info",
DlgImgBtnUpload		: "Saada serverissee",
DlgImgURL			: "URL",
DlgImgUpload		: "Lae üles",
DlgImgAlt			: "Alternatiivne tekst",
DlgImgWidth			: "Laius",
DlgImgHeight		: "Kõrgus",
DlgImgLockRatio		: "Lukusta kuvasuhe",
DlgBtnResetSize		: "Lähtesta suurus",
DlgImgBorder		: "Joon",
DlgImgHSpace		: "H. vaheruum",
DlgImgVSpace		: "V. vaheruum",
DlgImgAlign			: "Joondus",
DlgImgAlignLeft		: "Vasak",
DlgImgAlignAbsBottom: "Abs alla",
DlgImgAlignAbsMiddle: "Abs keskele",
DlgImgAlignBaseline	: "Baasjoonele",
DlgImgAlignBottom	: "Alla",
DlgImgAlignMiddle	: "Keskele",
DlgImgAlignRight	: "Paremale",
DlgImgAlignTextTop	: "Tekstit üles",
DlgImgAlignTop		: "Üles",
DlgImgPreview		: "Eelvaade",
DlgImgAlertUrl		: "Palun kirjuta pildi URL",
DlgImgLinkTab		: "Link",

// Flash Dialog
DlgFlashTitle		: "Flash omadused",
DlgFlashChkPlay		: "Automaatne start ",
DlgFlashChkLoop		: "Korduv",
DlgFlashChkMenu		: "Võimalda flash menüü",
DlgFlashScale		: "Mastaap",
DlgFlashScaleAll	: "Näita kõike",
DlgFlashScaleNoBorder	: "Äärist ei ole",
DlgFlashScaleFit	: "Täpne sobivus",

// Link Dialog
DlgLnkWindowTitle	: "Link",
DlgLnkInfoTab		: "Lingi info",
DlgLnkTargetTab		: "Sihtkoht",

DlgLnkType			: "Lingi tüüp",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "Ankur sellel lehel",
DlgLnkTypeEMail		: "E-post",
DlgLnkProto			: "Protokoll",
DlgLnkProtoOther	: "<muu>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "Vali ankur",
DlgLnkAnchorByName	: "Ankru nime järgi",
DlgLnkAnchorById	: "Elemendi id järgi",
DlgLnkNoAnchors		: "(Selles dokumendis ei ole ankruid)",
DlgLnkEMail			: "E-posti aadress",
DlgLnkEMailSubject	: "Sõnumi teema",
DlgLnkEMailBody		: "Sõnumi tekst",
DlgLnkUpload		: "Lae üles",
DlgLnkBtnUpload		: "Saada serverisse",

DlgLnkTarget		: "Sihtkoht",
DlgLnkTargetFrame	: "<raam>",
DlgLnkTargetPopup	: "<hüpikaken>",
DlgLnkTargetBlank	: "Uus aken (_blank)",
DlgLnkTargetParent	: "Esivanem aken (_parent)",
DlgLnkTargetSelf	: "Sama aken (_self)",
DlgLnkTargetTop		: "Pealmine aken (_top)",
DlgLnkTargetFrameName	: "Sihtmärk raami nimi",
DlgLnkPopWinName	: "Hüpikakna nimi",
DlgLnkPopWinFeat	: "Hüpikakna omadused",
DlgLnkPopResize		: "Suurendatav",
DlgLnkPopLocation	: "Aadressiriba",
DlgLnkPopMenu		: "Menüüriba",
DlgLnkPopScroll		: "Kerimisribad",
DlgLnkPopStatus		: "Olekuriba",
DlgLnkPopToolbar	: "Tööriistariba",
DlgLnkPopFullScrn	: "Täisekraan (IE)",
DlgLnkPopDependent	: "Sõltuv (Netscape)",
DlgLnkPopWidth		: "Laius",
DlgLnkPopHeight		: "Kõrgus",
DlgLnkPopLeft		: "Vasak asukoht",
DlgLnkPopTop		: "Ülemine asukoht",

DlnLnkMsgNoUrl		: "Palun kirjuta lingi URL",
DlnLnkMsgNoEMail	: "Palun kirjuta E-Posti aadress",
DlnLnkMsgNoAnchor	: "Palun vali ankur",
DlnLnkMsgInvPopName	: "Hüpikakna nimi peab algama alfabeetilise tähega ja ei tohi sisaldada tühikuid",

// Color Dialog
DlgColorTitle		: "Vali värv",
DlgColorBtnClear	: "Tühjenda",
DlgColorHighlight	: "Märgi",
DlgColorSelected	: "Valitud",

// Smiley Dialog
DlgSmileyTitle		: "Sisesta emotikon",

// Special Character Dialog
DlgSpecialCharTitle	: "Vali erimärk",

// Table Dialog
DlgTableTitle		: "Tabeli atribuudid",
DlgTableRows		: "Read",
DlgTableColumns		: "Veerud",
DlgTableBorder		: "Joone suurus",
DlgTableAlign		: "Joondus",
DlgTableAlignNotSet	: "<Määramata>",
DlgTableAlignLeft	: "Vasak",
DlgTableAlignCenter	: "Kesk",
DlgTableAlignRight	: "Parem",
DlgTableWidth		: "Laius",
DlgTableWidthPx		: "pikslit",
DlgTableWidthPc		: "protsenti",
DlgTableHeight		: "Kõrgus",
DlgTableCellSpace	: "Lahtri vahe",
DlgTableCellPad		: "Lahtri täidis",
DlgTableCaption		: "Tabeli tiitel",
DlgTableSummary		: "Kokkuvõte",
DlgTableHeaders		: "Headers",	//MISSING
DlgTableHeadersNone		: "None",	//MISSING
DlgTableHeadersColumn	: "First column",	//MISSING
DlgTableHeadersRow		: "First Row",	//MISSING
DlgTableHeadersBoth		: "Both",	//MISSING

// Table Cell Dialog
DlgCellTitle		: "Lahtri atribuudid",
DlgCellWidth		: "Laius",
DlgCellWidthPx		: "pikslit",
DlgCellWidthPc		: "protsenti",
DlgCellHeight		: "Kõrgus",
DlgCellWordWrap		: "Sõna ülekanne",
DlgCellWordWrapNotSet	: "<Määramata>",
DlgCellWordWrapYes	: "Jah",
DlgCellWordWrapNo	: "Ei",
DlgCellHorAlign		: "Horisontaaljoondus",
DlgCellHorAlignNotSet	: "<Määramata>",
DlgCellHorAlignLeft	: "Vasak",
DlgCellHorAlignCenter	: "Kesk",
DlgCellHorAlignRight: "Parem",
DlgCellVerAlign		: "Vertikaaljoondus",
DlgCellVerAlignNotSet	: "<Määramata>",
DlgCellVerAlignTop	: "Üles",
DlgCellVerAlignMiddle	: "Keskele",
DlgCellVerAlignBottom	: "Alla",
DlgCellVerAlignBaseline	: "Baasjoonele",
DlgCellType		: "Cell Type",	//MISSING
DlgCellTypeData		: "Data",	//MISSING
DlgCellTypeHeader	: "Header",	//MISSING
DlgCellRowSpan		: "Reaulatus",
DlgCellCollSpan		: "Veeruulatus",
DlgCellBackColor	: "Tausta värv",
DlgCellBorderColor	: "Joone värv",
DlgCellBtnSelect	: "Vali...",

// Find and Replace Dialog
DlgFindAndReplaceTitle	: "Otsi ja asenda",

// Find Dialog
DlgFindTitle		: "Otsi",
DlgFindFindBtn		: "Otsi",
DlgFindNotFoundMsg	: "Valitud teksti ei leitud.",

// Replace Dialog
DlgReplaceTitle			: "Asenda",
DlgReplaceFindLbl		: "Leia mida:",
DlgReplaceReplaceLbl	: "Asenda millega:",
DlgReplaceCaseChk		: "Erista suur- ja väiketähti",
DlgReplaceReplaceBtn	: "Asenda",
DlgReplaceReplAllBtn	: "Asenda kõik",
DlgReplaceWordChk		: "Otsi terviklike sõnu",

// Paste Operations / Dialog
PasteErrorCut	: "Sinu veebisirvija turvaseaded ei luba redaktoril automaatselt lõigata. Palun kasutage selleks klaviatuuri klahvikombinatsiooni (Ctrl+X).",
PasteErrorCopy	: "Sinu veebisirvija turvaseaded ei luba redaktoril automaatselt kopeerida. Palun kasutage selleks klaviatuuri klahvikombinatsiooni (Ctrl+C).",

PasteAsText		: "Kleebi tavalise tekstina",
PasteFromWord	: "Kleebi Wordist",

DlgPasteMsg2	: "Palun kleebi järgnevasse kasti kasutades klaviatuuri klahvikombinatsiooni (<STRONG>Ctrl+V</STRONG>) ja vajuta seejärel <STRONG>OK</STRONG>.",
DlgPasteSec		: "Sinu veebisirvija turvaseadete tõttu, ei oma redaktor otsest ligipääsu lõikelaua andmetele. Sa pead kleepima need uuesti siia aknasse.",
DlgPasteIgnoreFont		: "Ignoreeri kirja definitsioone",
DlgPasteRemoveStyles	: "Eemalda stiilide definitsioonid",

// Color Picker
ColorAutomatic	: "Automaatne",
ColorMoreColors	: "Rohkem värve...",

// Document Properties
DocProps		: "Dokumendi omadused",

// Anchor Dialog
DlgAnchorTitle		: "Ankru omadused",
DlgAnchorName		: "Ankru nimi",
DlgAnchorErrorName	: "Palun sisest ankru nimi",

// Speller Pages Dialog
DlgSpellNotInDic		: "Puudub sõnastikust",
DlgSpellChangeTo		: "Muuda",
DlgSpellBtnIgnore		: "Ignoreeri",
DlgSpellBtnIgnoreAll	: "Ignoreeri kõiki",
DlgSpellBtnReplace		: "Asenda",
DlgSpellBtnReplaceAll	: "Asenda kõik",
DlgSpellBtnUndo			: "Võta tagasi",
DlgSpellNoSuggestions	: "- Soovitused puuduvad -",
DlgSpellProgress		: "Toimub õigekirja kontroll...",
DlgSpellNoMispell		: "Õigekirja kontroll sooritatud: õigekirjuvigu ei leitud",
DlgSpellNoChanges		: "Õigekirja kontroll sooritatud: ühtegi sõna ei muudetud",
DlgSpellOneChange		: "Õigekirja kontroll sooritatud: üks sõna muudeti",
DlgSpellManyChanges		: "Õigekirja kontroll sooritatud: %1 sõna muudetud",

IeSpellDownload			: "Õigekirja kontrollija ei ole installeeritud. Soovid sa selle alla laadida?",

// Button Dialog
DlgButtonText		: "Tekst (väärtus)",
DlgButtonType		: "Tüüp",
DlgButtonTypeBtn	: "Nupp",
DlgButtonTypeSbm	: "Saada",
DlgButtonTypeRst	: "Lähtesta",

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Nimi",
DlgCheckboxValue	: "Väärtus",
DlgCheckboxSelected	: "Valitud",

// Form Dialog
DlgFormName		: "Nimi",
DlgFormAction	: "Toiming",
DlgFormMethod	: "Meetod",

// Select Field Dialog
DlgSelectName		: "Nimi",
DlgSelectValue		: "Väärtus",
DlgSelectSize		: "Suurus",
DlgSelectLines		: "ridu",
DlgSelectChkMulti	: "Võimalda mitu valikut",
DlgSelectOpAvail	: "Võimalikud valikud",
DlgSelectOpText		: "Tekst",
DlgSelectOpValue	: "Väärtus",
DlgSelectBtnAdd		: "Lisa",
DlgSelectBtnModify	: "Muuda",
DlgSelectBtnUp		: "Üles",
DlgSelectBtnDown	: "Alla",
DlgSelectBtnSetValue : "Sea valitud olekuna",
DlgSelectBtnDelete	: "Kustuta",

// Textarea Dialog
DlgTextareaName	: "Nimi",
DlgTextareaCols	: "Veerge",
DlgTextareaRows	: "Ridu",

// Text Field Dialog
DlgTextName			: "Nimi",
DlgTextValue		: "Väärtus",
DlgTextCharWidth	: "Laius (tähemärkides)",
DlgTextMaxChars		: "Maksimaalselt tähemärke",
DlgTextType			: "Tüüp",
DlgTextTypeText		: "Tekst",
DlgTextTypePass		: "Parool",

// Hidden Field Dialog
DlgHiddenName	: "Nimi",
DlgHiddenValue	: "Väärtus",

// Bulleted List Dialog
BulletedListProp	: "Täpitud loetelu omadused",
NumberedListProp	: "Nummerdatud loetelu omadused",
DlgLstStart			: "Alusta",
DlgLstType			: "Tüüp",
DlgLstTypeCircle	: "Ring",
DlgLstTypeDisc		: "Ketas",
DlgLstTypeSquare	: "Ruut",
DlgLstTypeNumbers	: "Numbrid (1, 2, 3)",
DlgLstTypeLCase		: "Väiketähed (a, b, c)",
DlgLstTypeUCase		: "Suurtähed (A, B, C)",
DlgLstTypeSRoman	: "Väiksed Rooma numbrid (i, ii, iii)",
DlgLstTypeLRoman	: "Suured Rooma numbrid (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Üldine",
DlgDocBackTab		: "Taust",
DlgDocColorsTab		: "Värvid ja veerised",
DlgDocMetaTab		: "Meta andmed",

DlgDocPageTitle		: "Lehekülje tiitel",
DlgDocLangDir		: "Kirja suund",
DlgDocLangDirLTR	: "Vasakult paremale (LTR)",
DlgDocLangDirRTL	: "Paremalt vasakule (RTL)",
DlgDocLangCode		: "Keele kood",
DlgDocCharSet		: "Märgistiku kodeering",
DlgDocCharSetCE		: "Kesk-Euroopa",
DlgDocCharSetCT		: "Hiina traditsiooniline (Big5)",
DlgDocCharSetCR		: "Kirillisa",
DlgDocCharSetGR		: "Kreeka",
DlgDocCharSetJP		: "Jaapani",
DlgDocCharSetKR		: "Korea",
DlgDocCharSetTR		: "Türgi",
DlgDocCharSetUN		: "Unicode (UTF-8)",
DlgDocCharSetWE		: "Lääne-Euroopa",
DlgDocCharSetOther	: "Ülejäänud märgistike kodeeringud",

DlgDocDocType		: "Dokumendi tüüppäis",
DlgDocDocTypeOther	: "Teised dokumendi tüüppäised",
DlgDocIncXHTML		: "Arva kaasa XHTML deklaratsioonid",
DlgDocBgColor		: "Taustavärv",
DlgDocBgImage		: "Taustapildi URL",
DlgDocBgNoScroll	: "Mittekeritav tagataust",
DlgDocCText			: "Tekst",
DlgDocCLink			: "Link",
DlgDocCVisited		: "Külastatud link",
DlgDocCActive		: "Aktiivne link",
DlgDocMargins		: "Lehekülje äärised",
DlgDocMaTop			: "Ülaserv",
DlgDocMaLeft		: "Vasakserv",
DlgDocMaRight		: "Paremserv",
DlgDocMaBottom		: "Alaserv",
DlgDocMeIndex		: "Dokumendi võtmesõnad (eraldatud komadega)",
DlgDocMeDescr		: "Dokumendi kirjeldus",
DlgDocMeAuthor		: "Autor",
DlgDocMeCopy		: "Autoriõigus",
DlgDocPreview		: "Eelvaade",

// Templates Dialog
Templates			: "Šabloon",
DlgTemplatesTitle	: "Sisu šabloonid",
DlgTemplatesSelMsg	: "Palun vali šabloon, et avada see redaktoris<br />(praegune sisu läheb kaotsi):",
DlgTemplatesLoading	: "Laen šabloonide nimekirja. Palun oota...",
DlgTemplatesNoTpl	: "(Ühtegi šablooni ei ole defineeritud)",
DlgTemplatesReplace	: "Asenda tegelik sisu",

// About Dialog
DlgAboutAboutTab	: "Teave",
DlgAboutBrowserInfoTab	: "Veebisirvija info",
DlgAboutLicenseTab	: "Litsents",
DlgAboutVersion		: "versioon",
DlgAboutInfo		: "Täpsema info saamiseks mine",

// Div Dialog
DlgDivGeneralTab	: "General",	//MISSING
DlgDivAdvancedTab	: "Advanced",	//MISSING
DlgDivStyle		: "Style",	//MISSING
DlgDivInlineStyle	: "Inline Style",	//MISSING

ScaytTitle			: "SCAYT",	//MISSING
ScaytTitleOptions	: "Options",	//MISSING
ScaytTitleLangs		: "Languages",	//MISSING
ScaytTitleAbout		: "About"	//MISSING
};
